@@ -17,8 +17,9 @@ from .imagenet.model_mobilenet import (mobilenet_imagenet,
 from .imagenet.model_vgg import (vgg_imagenet, vgg_imagenet_pretrained,
                                  vgg_melanoma_pretrained, vgg_odir5k_pretrained,
                                  vgg_retinal_oct_pretrained, vgg_ecg_pretrained)
-from .imagenet.model_mobilenet_edge import (mobilenet_edge_imagenet,
-                                            mobilenet_edge_imagenet_pretrained)
+from .imagenet.model_mobilenet_edge import (
+    mobilenet_edge_imagenet, mobilenet_edge_imagenet_pretrained,
+    mobilenet_faceidentification_edge_pretrained)
 from .kws.model_ds_cnn import ds_cnn_kws, ds_cnn_kws_pretrained
 from .modelnet40.model_pointnet_plus import (pointnet_plus_modelnet40,
                                              pointnet_plus_modelnet40_pretrained
