@@ -19,6 +19,7 @@ DS-CNN model definition for CIFAR10 classification.
 """
 
 from tensorflow.keras.layers import Input
+from tensorflow.keras.layers.experimental.preprocessing import Rescaling
 from tensorflow.keras import Model
 from tensorflow.keras.utils import get_file
 
@@ -33,7 +34,8 @@ def ds_cnn_cifar10(input_shape=(32, 32, 3),
                    classes=10,
                    weight_quantization=0,
                    activ_quantization=0,
-                   input_weight_quantization=None):
+                   input_weight_quantization=None,
+                   input_scaling=(255, 0)):
     """Instantiates a MobileNet-like model for the "CIFAR-10" example.
     This model is based on the MobileNet architecture, mainly with fewer layers.
     The weights and activations are quantized such that it can be converted into
@@ -62,6 +64,9 @@ def ds_cnn_cifar10(input_shape=(32, 32, 3),
             * 'None' implements the same bitwidth as the other weights.
             * '0' implements floating point 32-bit weights.
             * '2' through '8' implements n-bit weights where n is from 2-8 bits.
+        input_scaling (tuple, optional): scale factor and offset to apply to
+            inputs. Defaults to (255, 0). Note that following Akida convention,
+            the scale factor is an integer used as a divider.
 
     Returns:
         tf.keras.Model: a Keras model for DS-CNN/CIFAR-10
@@ -73,7 +78,13 @@ def ds_cnn_cifar10(input_shape=(32, 32, 3),
 
     img_input = Input(shape=input_shape)
 
-    x = conv_block(img_input,
+    if input_scaling is None:
+        x = img_input
+    else:
+        scale, offset = input_scaling
+        x = Rescaling(1. / scale, offset)(img_input)
+
+    x = conv_block(x,
                    filters=128,
                    name='conv_0',
                    kernel_size=(3, 3),
@@ -195,7 +206,7 @@ def ds_cnn_cifar10_pretrained():
 
     """
     model_name = 'ds_cnn_cifar10_iq4_wq4_aq4.h5'
-    file_hash = '01bea3a6fc2b9d088108ed4932572efb24254016a90fc58c3b85a0de68f868d4'
+    file_hash = '954f61fb6014a41a198cfa313fae5c40273614033da16b3f0f6b9a5db0ac642c'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
