@@ -19,6 +19,7 @@ VGG model definition for CIFAR10 classification.
 """
 
 from tensorflow.keras.layers import Input, Flatten
+from tensorflow.keras.layers.experimental.preprocessing import Rescaling
 from tensorflow.keras import Model
 from tensorflow.keras.utils import get_file
 
@@ -33,7 +34,8 @@ def vgg_cifar10(input_shape=(32, 32, 3),
                 classes=10,
                 weight_quantization=0,
                 activ_quantization=0,
-                input_weight_quantization=None):
+                input_weight_quantization=None,
+                input_scaling=(255, 0)):
     """Instantiates a VGG-like model for the "CIFAR-10" example.
     This model is based on the VGG architecture, mainly with fewer layers.
     The weights and activations are quantized such that it can be converted into
@@ -59,6 +61,9 @@ def vgg_cifar10(input_shape=(32, 32, 3),
             * 'None' implements the same bitwidth as the other weights.
             * '0' implements floating point 32-bit weights.
             * '2' through '8' implements n-bit weights where n is from 2-8 bits.
+        input_scaling (tuple, optional): scale factor and offset to apply to
+            inputs. Defaults to (255, 0). Note that following Akida convention,
+            the scale factor is an integer used as a divider.
 
     Returns:
         tf.keras.Model: a Keras model for VGG/CIFAR-10
@@ -69,7 +74,13 @@ def vgg_cifar10(input_shape=(32, 32, 3),
 
     img_input = Input(shape=input_shape)
 
-    x = conv_block(img_input,
+    if input_scaling is None:
+        x = img_input
+    else:
+        scale, offset = input_scaling
+        x = Rescaling(1. / scale, offset)(img_input)
+
+    x = conv_block(x,
                    filters=128,
                    kernel_size=(3, 3),
                    name='conv_0',
@@ -169,8 +180,8 @@ def vgg_cifar10_pretrained():
         tf.keras.Model: a Keras Model instance.
 
     """
-    model_name = 'vgg_cifar10_iq2_wq2_aq2.h5'
-    file_hash = '9f94ba8efc30877bc086cb77c22f220b26384f9c98cdae9e2cfb6c9e22a97033'
+    model_name = 'vgg_cifar10_iq8_wq4_aq4.h5'
+    file_hash = '4f67883ef8b149454acd1525c77021f9d032579b0653ada4732a0d21185013ae'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
