@@ -41,6 +41,7 @@ category 460 such segments are taken. Total size of the data thus becomes (4600,
 used for training.
 """
 
+import argparse
 import numpy as np
 import pandas as pd
 
@@ -48,7 +49,7 @@ from tensorflow.keras.utils import to_categorical
 
 from sklearn.model_selection import train_test_split
 
-from cnn2snn import load_quantized_model
+from cnn2snn import load_quantized_model, convert
 
 from ..training import get_training_parser, compile_model, evaluate_model
 
@@ -72,9 +73,10 @@ def get_data(data_file, input_size):
     category_labels = np.unique(labels)
     labels = pd.Categorical(labels, categories=category_labels).codes
 
-    # Rescale data to 8-bit, zero centered, range [-127, 127]
+    # Rescale data to 8-bit, range [0, 255], the model will rescale inputs so
+    # that they are zero centered (i.e [-127, 127])
     absmax = np.maximum(data.max(), -data.min())
-    data = np.round(data / absmax * 127)
+    data = np.round(data / absmax * 127) + 127
 
     # Split data: there are only 4600 examples in total in CWRU dataset, thus
     # keeping the test set at 1000 examples which is slightly above 21%.
@@ -114,14 +116,15 @@ def train_model(model, train_data, train_labels, batch_size, epochs):
 def main():
     """ Script entry point.
     """
-    parsers = get_training_parser(batch_size=128)
-    global_parser = parsers[1]
+    global_parser = argparse.ArgumentParser(add_help=False)
     global_parser.add_argument("-d",
                                "--data",
                                type=str,
                                default='./CWRU_48k_load_1_CNN_data.npz',
                                help="File path to the preprocessed npz data.")
-    args = parsers[0].parse_args()
+
+    parser = get_training_parser(batch_size=128, global_parser=global_parser)[0]
+    args = parser.parse_args()
 
     # Load the source model
     model = load_quantized_model(args.model)
@@ -145,10 +148,17 @@ def main():
 
     elif args.action == "eval":
         # Evaluate model accuracy
-        evaluate_model(model,
-                       test_data,
-                       y=test_labels,
-                       batch_size=args.batch_size)
+        if args.akida:
+            model = convert(model)
+            prediction_labels = model.predict(test_data.astype(np.uint8))
+            accuracy = (np.sum(prediction_labels == np.argmax(test_labels, 1)) /
+                        prediction_labels.shape[0])
+            print(f'Akida accuracy: {accuracy}')
+        else:
+            evaluate_model(model,
+                           test_data,
+                           y=test_labels,
+                           batch_size=args.batch_size)
 
 
 if __name__ == "__main__":
