@@ -133,8 +133,7 @@ class MapEvaluation(tf.keras.callbacks.Callback):
                 output = self._model.predict(input_image)[0]
             else:
                 image = preprocess_image(raw_image,
-                                         self._model.layers[0].input_dims,
-                                         False)
+                                         self._model.layers[0].input_dims)
                 input_image = image[np.newaxis, :].astype(np.uint8)
                 potentials = self._model.evaluate(input_image)[0]
 
