@@ -19,12 +19,13 @@ Training script for YOLO models.
 """
 
 import pickle
+import argparse
 
 from tensorflow.keras import Model
 from tensorflow.keras.layers import Reshape
 from tensorflow.keras.callbacks import EarlyStopping
 
-from cnn2snn import load_quantized_model
+from cnn2snn import load_quantized_model, convert
 
 from .yolo_loss import YoloLoss
 from .map_evaluation import MapEvaluation
@@ -118,7 +119,7 @@ def evaluate(model, valid_data, anchors, labels, obj_threshold, nms_threshold):
     """ Evaluates model performances.
 
     Args:
-        model (tf.keras.Model): the model to train
+        model (tf.keras.Model or akida.Model): the model to evaluate
         valid_data (dict): evaluation data
         anchors (list): list of anchors
         labels (list): list of labels
@@ -131,7 +132,8 @@ def evaluate(model, valid_data, anchors, labels, obj_threshold, nms_threshold):
                                   labels,
                                   anchors,
                                   obj_threshold=obj_threshold,
-                                  nms_threshold=nms_threshold)
+                                  nms_threshold=nms_threshold,
+                                  is_keras_model=isinstance(model, Model))
 
     # Compute mAP scores and display them
     mAP, average_precisions = map_evaluator.evaluate_map()
@@ -143,8 +145,7 @@ def evaluate(model, valid_data, anchors, labels, obj_threshold, nms_threshold):
 def main():
     """ Entry point for script and CLI usage.
     """
-    parsers = get_training_parser(batch_size=128, freeze_before=True, tune=True)
-    global_parser = parsers[1]
+    global_parser = argparse.ArgumentParser(add_help=False)
     global_parser.add_argument(
         "-d",
         "--data",
@@ -165,7 +166,12 @@ def main():
                                type=float,
                                default=0.5,
                                help="Non-Maximal Suppression threshold.")
-    args = parsers[0].parse_args()
+
+    parser = get_training_parser(batch_size=128,
+                                 freeze_before=True,
+                                 tune=True,
+                                 global_parser=global_parser)[0]
+    args = parser.parse_args()
 
     # Load data
     train_data, valid_data, labels, anchors = get_data(args.data,
@@ -211,6 +217,11 @@ def main():
 
     elif args.action == 'eval':
         # Evaluate model accuracy
+        if args.akida:
+            # Drop the last reshape layer that is not Akida compatible
+            if model.layers[-1].name == 'YOLO_output':
+                model = Model(model.input, model.layers[-2].output)
+            model = convert(model)
         evaluate(model, valid_data, anchors, labels, args.obj_thresh,
                  args.nms_thresh)
 
