@@ -19,6 +19,7 @@ Training script for DVS models.
 """
 
 import os
+import argparse
 import numpy as np
 
 import tensorflow as tf
@@ -174,11 +175,7 @@ def train_model(model, train_set, test_set, class_list, sample_repeats,
 def main():
     """ Entry point for script and CLI usage.
     """
-    parsers = get_training_parser(batch_size=32,
-                                  tune=True,
-                                  global_batch_size=False)
-
-    global_parser = parsers[1]
+    global_parser = argparse.ArgumentParser(add_help=False)
     global_parser.add_argument("-d",
                                "--dataset",
                                type=str,
@@ -186,7 +183,12 @@ def main():
                                choices=['dvs_gesture', 'samsung_handy'],
                                help="Dataset name (defaut=dvs_gesture)")
 
-    tune_parser = parsers[3]
+    parsers = get_training_parser(batch_size=32,
+                                  tune=True,
+                                  global_batch_size=False,
+                                  global_parser=global_parser)
+
+    tune_parser = parsers[2]
     tune_parser.add_argument("-ft",
                              "--fine_tune",
                              type=bool,
@@ -209,15 +211,6 @@ def main():
     train_data, x_test, y_test, class_list, sample_repeats = get_data(
         args.dataset)
 
-    # Convert to Akida
-    if args.action == "convert":
-        model_ak = convert(model, input_is_image=False)
-
-        # Save model in Akida format (fbz)
-        if args.savemodel:
-            model_ak.save(args.savemodel)
-            print(f"Converted model saved as {args.savemodel}")
-
     # Train model
     if args.action in ["train", "tune"]:
         train_model(model=model,
@@ -236,7 +229,13 @@ def main():
 
     elif args.action == "eval":
         # Evaluate model accuracy
-        evaluate_model(model, x_test, y=y_test)
+        if args.akida:
+            model_ak = convert(model, input_is_image=False)
+            preds = model_ak.predict(np.swapaxes(x_test, 1, 2).astype('uint8'))
+            accuracy = (np.argmax(y_test, 1) == preds).mean()
+            print(f"Akida accuracy: {accuracy}")
+        else:
+            evaluate_model(model, x_test, y=y_test)
 
 
 if __name__ == "__main__":
