@@ -102,7 +102,25 @@ def mobilenet_edge_imagenet_pretrained():
 
     """
     model_name = 'mobilenet_imagenet_224_alpha_50_edge_iq8_wq4_aq4.h5'
-    file_hash = 'f2d062221741aa538b897016459df1ed93f28d666ea90fbb699b5b8d57fec5e5'
+    file_hash = 'b759ed6aa5b47923e5cee03f756e63d7a5865e49f34749e55aff242d83b9ee75'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
+
+
+def mobilenet_faceidentification_edge_pretrained():
+    """
+    Helper method to retrieve a `mobilenet_edge_imagenet` model that was trained
+    on CASIA Webface dataset and that performs face identification.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'mobilenet_faceidentification_edge_iq8_wq4_aq4.h5'
+    file_hash = '62958a630dbcaa79ec12f0071870788231cb96f27e5d7c86e37927696c04a4a8'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
