@@ -652,9 +652,7 @@ def resize_and_crop(image_buffer, output_height, output_width, num_channels):
                              output_height=output_height,
                              output_width=output_width,
                              num_channels=num_channels,
-                             is_training=False,
-                             alpha=1.,
-                             beta=0.)
+                             is_training=False)
 
     image = tf.cast(image, tf.uint8)
     return np.expand_dims(image.numpy(), axis=0)
@@ -666,8 +664,6 @@ def preprocess_image(image_buffer,
                      output_width,
                      num_channels,
                      is_training=False,
-                     alpha=128.,
-                     beta=128.,
                      decode=True):
     """Preprocesses the given image.
 
@@ -709,15 +705,7 @@ def preprocess_image(image_buffer,
     image.set_shape([output_height, output_width, num_channels])
 
     # Convert image to float in case the resize didn't
-    image = tf.cast(image, tf.float32)
-
-    # Here, we change the mean value to subtract from the image because Akida
-    # supports a single beta value for all channels.
-    #return _mean_image_subtraction(image, CHANNEL_MEANS, num_channels)
-    image = _mean_image_subtraction(image, [beta, beta, beta], num_channels)
-
-    # Divide by alpha
-    return tf.math.scalar_mul(1 / alpha, image)
+    return tf.cast(image, tf.float32)
 
 
 def index_to_label(index):
