@@ -23,7 +23,7 @@ import pickle
 
 from tensorflow.keras.utils import to_categorical, get_file
 
-from cnn2snn import load_quantized_model, quantize_layer
+from cnn2snn import load_quantized_model, quantize_layer, convert
 
 from ..cyclic_lr import CyclicLR
 from ..training import get_training_parser, compile_model, evaluate_model
@@ -35,11 +35,6 @@ def get_data():
     Returns:
         tuple: train data, train labels, validation data and validation labels
     """
-    # Input scaling: Akida is configured to take 8-bit inputs without rescaling
-    # but for the training, we use float weights between 0 and 1
-    a = 255
-    b = 0
-
     # Load pre-processed dataset
     fname = get_file(
         fname='kws_preprocessed_all_words_except_backward_follow_forward.pkl',
@@ -49,15 +44,9 @@ def get_data():
 
     print('Loading pre-processed dataset...')
     with open(fname, 'rb') as f:
-        [x_train_ak, y_train, x_val_ak, y_val, _, _, _, _] = pickle.load(f)
+        [x_train, y_train, x_val, y_val, _, _, _, _] = pickle.load(f)
 
-    # For cnn2snn Keras training, data must be scaled (usually to [0,1])
-    x_train_keras = \
-        (x_train_ak.astype('float32') - b) / a
-    x_val_keras = \
-        (x_val_ak.astype('float32') - b) / a
-
-    return x_train_keras, y_train, x_val_keras, y_val
+    return x_train.astype('float32'), y_train, x_val.astype('float32'), y_val
 
 
 def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
@@ -105,7 +94,7 @@ def main():
     """
     parsers = get_training_parser(batch_size=100, global_batch_size=False)
 
-    train_parser = parsers[2]
+    train_parser = parsers[1]
     train_parser.add_argument("-laq",
                               "--last_activ_quantization",
                               type=int,
@@ -140,7 +129,13 @@ def main():
 
     elif args.action == "eval":
         # Evaluate model accuracy
-        evaluate_model(model, x_val, y=to_categorical(y_val))
+        if args.akida:
+            model_ak = convert(model)
+            preds = model_ak.predict(x_val.astype('uint8'))
+            accuracy = (y_val == preds).mean()
+            print(f"Accuracy: {accuracy}")
+        else:
+            evaluate_model(model, x_val, y=to_categorical(y_val))
 
 
 if __name__ == "__main__":
