@@ -20,6 +20,7 @@ DS-CNN model definition for KWS classification.
 
 from tensorflow.keras import Model
 from tensorflow.keras.layers import Input, Reshape, Activation, Flatten
+from tensorflow.keras.layers.experimental.preprocessing import Rescaling
 from tensorflow.keras.utils import get_file
 
 from cnn2snn import load_quantized_model, quantize, quantize_layer
@@ -35,7 +36,8 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
                weight_quantization=0,
                activ_quantization=0,
                input_weight_quantization=None,
-               last_layer_activ_quantization=None):
+               last_layer_activ_quantization=None,
+               input_scaling=(255, 0)):
     """Instantiates a MobileNet-like model for the "Keyword Spotting" example.
 
     This model is based on the MobileNet architecture, mainly with fewer layers.
@@ -75,6 +77,9 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
             * 'None' implements the same bitwidth as the other activations.
             * '0' implements floating point 32-bit activations.
             * '1' through '8' implements n-bit weights where n is from 2-8 bits.
+        input_scaling (tuple, optional): scale factor and offset to apply to
+            inputs. Defaults to (255, 0). Note that following Akida convention,
+            the scale factor is an integer used as a divider.
 
     Returns:
         tf.keras.Model: a Keras model for MobileNet/KWS
@@ -90,7 +95,13 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
 
     img_input = Input(shape=input_shape)
 
-    x = conv_block(img_input,
+    if input_scaling is None:
+        x = img_input
+    else:
+        scale, offset = input_scaling
+        x = Rescaling(1. / scale, offset)(img_input)
+
+    x = conv_block(x,
                    filters=32,
                    kernel_size=(5, 5),
                    padding='same',
@@ -190,7 +201,7 @@ def ds_cnn_kws_pretrained():
 
     """
     model_name = 'ds_cnn_kws_iq8_wq4_aq4_laq1.h5'
-    file_hash = 'a26240d2e284b7ecd2634f8cd77366c0a4c7bd4f39e4bde4aa7d14d5d860e09e'
+    file_hash = 'cd56ca58ee1330bee8cc9ab52e6d18d52c69d2ff93457dd95f341243b7efb2d7'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
