@@ -215,7 +215,8 @@ class AudioProcessor():
             print(
                 f"Successfully downloaded {filename} ({statinfo.st_size} bytes)"
             )
-        tarfile.open(filepath, 'r:gz').extractall(dest_directory)
+        with tarfile.open(filepath, 'r:gz') as tar:
+            tar.extractall(dest_directory)
 
     def prepare_data_index(self, silence_percentage, unknown_percentage,
                            wanted_words, validation_percentage,
