@@ -91,10 +91,10 @@ def conv_block(inputs,
     Returns:
         tf.Tensor: output tensor of conv2D block.
     """
-    if 'activation' in kwargs.keys() and kwargs['activation']:
+    if 'activation' in kwargs and kwargs['activation']:
         raise ValueError(
             "Keyword argument 'activation' in conv_block must be None.")
-    if 'dilation_rate' in kwargs.keys():
+    if 'dilation_rate' in kwargs:
         if kwargs['dilation_rate'] != 1 and kwargs['dilation_rate'] != (1, 1):
             raise ValueError("Keyword argument 'dilation_rate' is not "
                              "supported in conv_block.")
@@ -149,14 +149,14 @@ def separable_conv_block(inputs,
     Returns:
         tf.Tensor: output tensor of separable conv block.
     """
-    if 'activation' in kwargs.keys() and kwargs['activation']:
+    if 'activation' in kwargs and kwargs['activation']:
         raise ValueError("Keyword argument 'activation' in separable_conv_block"
                          " must be None.")
-    if 'dilation_rate' in kwargs.keys():
+    if 'dilation_rate' in kwargs:
         if kwargs['dilation_rate'] != 1 and kwargs['dilation_rate'] != (1, 1):
             raise ValueError("Keyword argument 'dilation_rate' is not "
                              "supported in separable_conv_block.")
-    if 'depth_multiplier' in kwargs.keys():
+    if 'depth_multiplier' in kwargs:
         if kwargs['depth_multiplier'] != 1:
             raise ValueError("Keyword argument 'depth_multiplier' is not "
                              "supported in separable_conv_block.")
@@ -196,7 +196,7 @@ def dense_block(inputs,
     Returns:
         tf.Tensor: output tensor of the dense block.
     """
-    if 'activation' in kwargs.keys() and kwargs['activation']:
+    if 'activation' in kwargs and kwargs['activation']:
         raise ValueError("Keyword argument 'activation' in dense_block"
                          " must be None.")
 
