@@ -19,8 +19,11 @@ Common utility methods used by the training scripts.
 """
 
 import argparse
+import numpy as np
+import tensorflow as tf
 
 from tensorflow.keras.optimizers import Adam
+from tensorflow.keras.layers import Activation
 
 
 def compile_model(model,
@@ -97,10 +100,55 @@ def evaluate_model(model,
         print('Validation accuracy: ', history[1])
 
 
+def evaluate_akida_model(model, x, activation):
+    """ Evaluates Akida model and return predictions and labels to compute
+    accuracy.
+
+    Args:
+        model (akida.Model): the model to evaluate
+        x (tf.Dataset, np.array or generator): evaluation input data
+        activation (str): activation function to apply to potentials
+
+    Returns:
+        np.array, np.array: predictions and labels
+    """
+
+    # Initialize to None to allow different shapes depending on the caller
+    labels = None
+    pots = None
+
+    # Datasets created as ImageDataGenerator will be looped over indefinitely,
+    # they thus need a special treatment
+    steps = None
+    if isinstance(x, tf.keras.preprocessing.image.DirectoryIterator):
+        steps = np.math.ceil(x.samples / x.batch_size)
+
+    for batch, label_batch in x:
+        if not isinstance(batch, np.ndarray):
+            batch = batch.numpy()
+
+        pots_batch = model.evaluate(batch.astype('uint8'))
+
+        if labels is None:
+            labels = label_batch
+            pots = pots_batch.squeeze()
+        else:
+            labels = np.concatenate((labels, label_batch))
+            pots = np.concatenate((pots, pots_batch.squeeze()))
+
+        # End the for loop if the number of batches has reached the number of
+        # steps
+        if steps is not None and x.total_batches_seen == steps:
+            break
+
+    return Activation(activation)(pots), labels
+
+
 def get_training_parser(batch_size,
                         tune=False,
                         freeze_before=False,
-                        global_batch_size=True):
+                        global_batch_size=True,
+                        global_parser=None):
     """ Instantiates a base arguments parser for training scripts.
 
     The returned parser comes with train, tune and eval actions as subparsers
@@ -115,13 +163,14 @@ def get_training_parser(batch_size,
         global_batch_size (bool, optional): either to add batch size as a
             global parser parameter or for train/tune actions only. Default to
             True.
+        global_parser (argparse.ArgumentParser, optional): global parser with
+            custom parameters. Defaults to None.
 
     Returns:
         argparse.ArgumentParser, argparse.ArgumentParser,
         argparse.ArgumentParser, argparse.ArgumentParser,
-        argparse.ArgumentParser, argparse._SubParsersAction: main parser, global
-            parser and, train, tune and eval actions subparsers and the
-            subparser object.
+        argparse._SubParsersAction: main parser and train, tune and eval actions
+            subparsers and the subparser object.
     """
 
     # Define a strictly positive int type for parameters
@@ -135,7 +184,9 @@ def get_training_parser(batch_size,
     parser = argparse.ArgumentParser()
 
     # Base arguments
-    global_parser = argparse.ArgumentParser(add_help=False)
+    if global_parser is None:
+        global_parser = argparse.ArgumentParser(add_help=False)
+
     global_parser.add_argument("-m",
                                "--model",
                                type=str,
@@ -196,4 +247,9 @@ def get_training_parser(batch_size,
                                         help="Evaluate a model",
                                         parents=[global_parser])
 
-    return parser, global_parser, train_parser, tune_parser, eval_parser, subparsers
+    eval_parser.add_argument("-ak",
+                             "--akida",
+                             action='store_true',
+                             help="Converts to an Akida model and evaluate")
+
+    return parser, train_parser, tune_parser, eval_parser, subparsers
