@@ -20,6 +20,7 @@ VGG model definition for UTKFace regression.
 
 from tensorflow.keras import Model
 from tensorflow.keras.layers import Dropout, Flatten, Input
+from tensorflow.keras.layers.experimental.preprocessing import Rescaling
 from tensorflow.keras.utils import get_file
 
 from cnn2snn import load_quantized_model, quantize
@@ -32,7 +33,8 @@ BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/vgg/'
 def vgg_utk_face(input_shape=(32, 32, 3),
                  weight_quantization=0,
                  activ_quantization=0,
-                 input_weight_quantization=None):
+                 input_weight_quantization=None,
+                 input_scaling=(127, -1)):
     """Instantiates a VGG-like model for the regression example on age
     estimation using UTKFace dataset.
 
@@ -55,6 +57,9 @@ def vgg_utk_face(input_shape=(32, 32, 3),
             * 'None' implements the same bitwidth as the other weights.
             * '0' implements floating point 32-bit weights.
             * '2' through '8' implements n-bit weights where n is from 2-8 bits.
+        input_scaling (tuple, optional): scale factor and offset to apply to
+            inputs. Defaults to (127, -1). Note that following Akida convention,
+            the scale factor is an integer used as a divider.
 
     Returns:
         tf.keras.Model: a Keras model for VGG/UTKFace
@@ -65,7 +70,13 @@ def vgg_utk_face(input_shape=(32, 32, 3),
 
     img_input = Input(shape=input_shape)
 
-    x = conv_block(img_input,
+    if input_scaling is None:
+        x = img_input
+    else:
+        scale, offset = input_scaling
+        x = Rescaling(1. / scale, offset)(img_input)
+
+    x = conv_block(x,
                    filters=32,
                    kernel_size=(3, 3),
                    name='conv_0',
@@ -148,7 +159,7 @@ def vgg_utk_face_pretrained():
 
     """
     model_name = 'vgg_utk_face_iq8_wq2_aq2.h5'
-    file_hash = 'c5f7c722c19dd1f2f9743acd8d315b0ef51adb1f2dd42138b1e34c5f81782b96'
+    file_hash = 'e688686ad311e36f14e49c720e85461620b7406329cef00fa7afe79b33080b01'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
