@@ -17,10 +17,11 @@
 """
 Training script for UTKFace model.
 """
+import numpy as np
 
 from tensorflow.keras.callbacks import LearningRateScheduler
 
-from cnn2snn import load_quantized_model
+from cnn2snn import load_quantized_model, convert
 
 from ..training import get_training_parser, compile_model, evaluate_model
 from .preprocessing import load_data
@@ -36,17 +37,7 @@ def get_data():
     # Load the dataset
     x_train, y_train, x_test, y_test = load_data()
 
-    # Input_scaling
-    a = 127
-    b = 127
-
-    x_train = x_train.astype('float32')
-    x_test = x_test.astype('float32')
-
-    x_train = (x_train - b) / a
-    x_test = (x_test - b) / a
-
-    return x_train, y_train, x_test, y_test
+    return x_train.astype('float32'), y_train, x_test.astype('float32'), y_test
 
 
 def train_model(model, x_train, y_train, x_test, y_test, epochs, batch_size):
@@ -106,7 +97,13 @@ def main():
 
     elif args.action == "eval":
         # Evaluate model accuracy
-        evaluate_model(model, x_test, y=y_test, print_history=True)
+        if args.akida:
+            model_ak = convert(model)
+            y = model_ak.evaluate(x_test)
+            mae = np.sum(np.abs(y_test.squeeze() - y.squeeze())) / len(y_test)
+            print("Validation accuracy: {0:.4f}".format(mae))
+        else:
+            evaluate_model(model, x_test, y=y_test, print_history=True)
 
 
 if __name__ == "__main__":
